# NAME

WWW::SwaggerClient::Role - a Moose role for the Figshare API

Figshare apiv2. Using Swagger 2.0

# VERSION

Automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PerlClientCodegen

## A note on Moose

This role is the only component of the library that uses Moose. See
WWW::SwaggerClient::ApiFactory for non-Moosey usage.

# SYNOPSIS

The Perl Swagger Codegen project builds a library of Perl modules to interact with
a web service defined by a OpenAPI Specification. See below for how to build the
library.

This module provides an interface to the generated library. All the classes,
objects, and methods (well, not quite \*all\*, see below) are flattened into this
role.

        package MyApp;
        use Moose;
        with 'WWW::SwaggerClient::Role';

        package main;

        my $api = MyApp->new({ tokens => $tokens });

        my $pet = $api->get_pet_by_id(pet_id => $pet_id);


## Structure of the library

The library consists of a set of API classes, one for each endpoint. These APIs
implement the method calls available on each endpoint.

Additionally, there is a set of "object" classes, which represent the objects
returned by and sent to the methods on the endpoints.

An API factory class is provided, which builds instances of each endpoint API.

This Moose role flattens all the methods from the endpoint APIs onto the consuming
class. It also provides methods to retrieve the endpoint API objects, and the API
factory object, should you need it.

For documentation of all these methods, see AUTOMATIC DOCUMENTATION below.

## Configuring authentication

In the normal case, the OpenAPI Spec will describe what parameters are
required and where to put them. You just need to supply the tokens.

    my $tokens = {
        # basic
        username => $username,
        password => $password,

        # oauth
        access_token => $oauth_token,

        # keys
        $some_key => { token => $token,
                       prefix => $prefix,
                       in => $in,             # 'head||query',
                       },

        $another => { token => $token,
                      prefix => $prefix,
                      in => $in,              # 'head||query',
                      },
        ...,

        };

        my $api = MyApp->new({ tokens => $tokens });

Note these are all optional, as are `prefix` and `in`, and depend on the API
you are accessing. Usually `prefix` and `in` will be determined by the code generator from
the spec and you will not need to set them at run time. If not, `in` will
default to 'head' and `prefix` to the empty string.

The tokens will be placed in a L<WWW::SwaggerClient::Configuration> instance
as follows, but you don't need to know about this.

- `$cfg->{username}`

    String. The username for basic auth.

- `$cfg->{password}`

    String. The password for basic auth.

- `$cfg->{api_key}`

    Hashref. Keyed on the name of each key (there can be multiple tokens).

            $cfg->{api_key} = {
                    secretKey => 'aaaabbbbccccdddd',
                    anotherKey => '1111222233334444',
                    };

- `$cfg->{api_key_prefix}`

    Hashref. Keyed on the name of each key (there can be multiple tokens). Note not
    all api keys require a prefix.

            $cfg->{api_key_prefix} = {
                    secretKey => 'string',
                    anotherKey => 'same or some other string',
                    };

- `$cfg->{access_token}`

    String. The OAuth access token.

# METHODS

## `base_url`

The generated code has the `base_url` already set as a default value. This method
returns the current value of `base_url`.

## `api_factory`

Returns an API factory object. You probably won't need to call this directly.

        $self->api_factory('Pet'); # returns a WWW::SwaggerClient::PetApi instance

        $self->pet_api;            # the same

# MISSING METHODS

Most of the methods on the API are delegated to individual endpoint API objects
(e.g. Pet API, Store API, User API etc). Where different endpoint APIs use the
same method name (e.g. `new()`), these methods can't be delegated. So you need
to call `$api->pet_api->new()`.

In principle, every API is susceptible to the presence of a few, random, undelegatable
method names. In practice, because of the way method names are constructed, it's
unlikely in general that any methods will be undelegatable, except for:

        new()
        class_documentation()
        method_documentation()

To call these methods, you need to get a handle on the relevant object, either
by calling `$api->foo_api` or by retrieving an object, e.g.
`$api->get_pet_by_id(pet_id => $pet_id)`. They are class methods, so
you could also call them on class names.

# BUILDING YOUR LIBRARY

See the homepage `https://github.com/swagger-api/swagger-codegen` for full details.
But briefly, clone the git repository, build the codegen codebase, set up your build
config file, then run the API build script. You will need git, Java 7 or 8 and Apache
maven 3.0.3 or better already installed.

The config file should specify the project name for the generated library:

        {"moduleName":"WWW::MyProjectName"}

Your library files will be built under `WWW::MyProjectName`.

          $ git clone https://github.com/swagger-api/swagger-codegen.git
          $ cd swagger-codegen
          $ mvn package
          $ java -jar modules/swagger-codegen-cli/target/swagger-codegen-cli.jar generate \
    -i [URL or file path to JSON swagger API spec] \
    -l perl \
    -c /path/to/config/file.json \
    -o /path/to/output/folder

Bang, all done. Run the `autodoc` script in the `bin` directory to see the API
you just built.

# AUTOMATIC DOCUMENTATION

You can print out a summary of the generated API by running the included
`autodoc` script in the `bin` directory of your generated library. A few
output formats are supported:

          Usage: autodoc [OPTION]

    -w           wide format (default)
    -n           narrow format
    -p           POD format
    -H           HTML format
    -m           Markdown format
    -h           print this help message
    -c           your application class


The `-c` option allows you to load and inspect your own application. A dummy
namespace is used if you don't supply your own class.

# DOCUMENTATION FROM THE OpenAPI Spec

Additional documentation for each class and method may be provided by the Swagger
spec. If so, this is available via the `class_documentation()` and
`method_documentation()` methods on each generated object class, and the
`method_documentation()` method on the endpoint API classes:

        my $cmdoc = $api->pet_api->method_documentation->{$method_name};

        my $odoc = $api->get_pet_by_id->(pet_id => $pet_id)->class_documentation;
        my $omdoc = $api->get_pet_by_id->(pet_id => $pet_id)->method_documentation->{method_name};


Each of these calls returns a hashref with various useful pieces of information.

# LOAD THE MODULES

To load the API packages:
```perl
use WWW::SwaggerClient::ArticlesApi;
use WWW::SwaggerClient::AuthorsApi;
use WWW::SwaggerClient::CollectionsApi;
use WWW::SwaggerClient::InstitutionsApi;
use WWW::SwaggerClient::OtherApi;
use WWW::SwaggerClient::ProjectsApi;

```

To load the models:
```perl
use WWW::SwaggerClient::Object::Account;
use WWW::SwaggerClient::Object::AccountCreate;
use WWW::SwaggerClient::Object::AccountGroupRoles;
use WWW::SwaggerClient::Object::AccountGroupRolesCreate;
use WWW::SwaggerClient::Object::AccountReport;
use WWW::SwaggerClient::Object::AccountUpdate;
use WWW::SwaggerClient::Object::Article;
use WWW::SwaggerClient::Object::ArticleComplete;
use WWW::SwaggerClient::Object::ArticleCompletePrivate;
use WWW::SwaggerClient::Object::ArticleConfidentiality;
use WWW::SwaggerClient::Object::ArticleCreate;
use WWW::SwaggerClient::Object::ArticleDOI;
use WWW::SwaggerClient::Object::ArticleEmbargo;
use WWW::SwaggerClient::Object::ArticleEmbargoUpdater;
use WWW::SwaggerClient::Object::ArticleHandle;
use WWW::SwaggerClient::Object::ArticleProjectCreate;
use WWW::SwaggerClient::Object::ArticleSearch;
use WWW::SwaggerClient::Object::ArticleUpdate;
use WWW::SwaggerClient::Object::ArticleVersions;
use WWW::SwaggerClient::Object::ArticleWithProject;
use WWW::SwaggerClient::Object::ArticlesCreator;
use WWW::SwaggerClient::Object::Author;
use WWW::SwaggerClient::Object::AuthorComplete;
use WWW::SwaggerClient::Object::AuthorsCreator;
use WWW::SwaggerClient::Object::CategoriesCreator;
use WWW::SwaggerClient::Object::Category;
use WWW::SwaggerClient::Object::Collaborator;
use WWW::SwaggerClient::Object::Collection;
use WWW::SwaggerClient::Object::CollectionComplete;
use WWW::SwaggerClient::Object::CollectionCompletePrivate;
use WWW::SwaggerClient::Object::CollectionCreate;
use WWW::SwaggerClient::Object::CollectionDOI;
use WWW::SwaggerClient::Object::CollectionHandle;
use WWW::SwaggerClient::Object::CollectionPrivateLinkCreator;
use WWW::SwaggerClient::Object::CollectionSearch;
use WWW::SwaggerClient::Object::CollectionUpdate;
use WWW::SwaggerClient::Object::CollectionVersions;
use WWW::SwaggerClient::Object::CommonSearch;
use WWW::SwaggerClient::Object::ConfidentialityCreator;
use WWW::SwaggerClient::Object::CreateProjectResponse;
use WWW::SwaggerClient::Object::Curation;
use WWW::SwaggerClient::Object::CurationComment;
use WWW::SwaggerClient::Object::CurationCommentCreate;
use WWW::SwaggerClient::Object::CurationDetail;
use WWW::SwaggerClient::Object::CustomArticleField;
use WWW::SwaggerClient::Object::CustomArticleFieldAdd;
use WWW::SwaggerClient::Object::ErrorMessage;
use WWW::SwaggerClient::Object::FileCreator;
use WWW::SwaggerClient::Object::FileId;
use WWW::SwaggerClient::Object::FundingCreate;
use WWW::SwaggerClient::Object::FundingInformation;
use WWW::SwaggerClient::Object::FundingSearch;
use WWW::SwaggerClient::Object::Group;
use WWW::SwaggerClient::Object::GroupEmbargoOptions;
use WWW::SwaggerClient::Object::Institution;
use WWW::SwaggerClient::Object::InstitutionAccountsSearch;
use WWW::SwaggerClient::Object::ItemType;
use WWW::SwaggerClient::Object::License;
use WWW::SwaggerClient::Object::Location;
use WWW::SwaggerClient::Object::LocationWarnings;
use WWW::SwaggerClient::Object::LocationWarningsUpdate;
use WWW::SwaggerClient::Object::PrivateArticleSearch;
use WWW::SwaggerClient::Object::PrivateAuthorsSearch;
use WWW::SwaggerClient::Object::PrivateCollectionSearch;
use WWW::SwaggerClient::Object::PrivateFile;
use WWW::SwaggerClient::Object::PrivateLink;
use WWW::SwaggerClient::Object::PrivateLinkCreator;
use WWW::SwaggerClient::Object::PrivateLinkResponse;
use WWW::SwaggerClient::Object::Project;
use WWW::SwaggerClient::Object::ProjectArticle;
use WWW::SwaggerClient::Object::ProjectCollaborator;
use WWW::SwaggerClient::Object::ProjectCollaboratorInvite;
use WWW::SwaggerClient::Object::ProjectComplete;
use WWW::SwaggerClient::Object::ProjectCompletePrivate;
use WWW::SwaggerClient::Object::ProjectCreate;
use WWW::SwaggerClient::Object::ProjectNote;
use WWW::SwaggerClient::Object::ProjectNoteCreate;
use WWW::SwaggerClient::Object::ProjectNotePrivate;
use WWW::SwaggerClient::Object::ProjectPrivate;
use WWW::SwaggerClient::Object::ProjectUpdate;
use WWW::SwaggerClient::Object::ProjectsSearch;
use WWW::SwaggerClient::Object::PublicFile;
use WWW::SwaggerClient::Object::RelatedMaterial;
use WWW::SwaggerClient::Object::Resource;
use WWW::SwaggerClient::Object::ResponseMessage;
use WWW::SwaggerClient::Object::Role;
use WWW::SwaggerClient::Object::ShortAccount;
use WWW::SwaggerClient::Object::ShortCustomField;
use WWW::SwaggerClient::Object::Timeline;
use WWW::SwaggerClient::Object::TimelineUpdate;
use WWW::SwaggerClient::Object::UploadFilePart;
use WWW::SwaggerClient::Object::UploadInfo;
use WWW::SwaggerClient::Object::User;

````

# GETTING STARTED
Put the Perl SDK under the 'lib' folder in your project directory, then run the following
```perl
#!/usr/bin/perl
use lib 'lib';
use strict;
use warnings;
# load the API package
use WWW::SwaggerClient::ArticlesApi;
use WWW::SwaggerClient::AuthorsApi;
use WWW::SwaggerClient::CollectionsApi;
use WWW::SwaggerClient::InstitutionsApi;
use WWW::SwaggerClient::OtherApi;
use WWW::SwaggerClient::ProjectsApi;

# load the models
use WWW::SwaggerClient::Object::Account;
use WWW::SwaggerClient::Object::AccountCreate;
use WWW::SwaggerClient::Object::AccountGroupRoles;
use WWW::SwaggerClient::Object::AccountGroupRolesCreate;
use WWW::SwaggerClient::Object::AccountReport;
use WWW::SwaggerClient::Object::AccountUpdate;
use WWW::SwaggerClient::Object::Article;
use WWW::SwaggerClient::Object::ArticleComplete;
use WWW::SwaggerClient::Object::ArticleCompletePrivate;
use WWW::SwaggerClient::Object::ArticleConfidentiality;
use WWW::SwaggerClient::Object::ArticleCreate;
use WWW::SwaggerClient::Object::ArticleDOI;
use WWW::SwaggerClient::Object::ArticleEmbargo;
use WWW::SwaggerClient::Object::ArticleEmbargoUpdater;
use WWW::SwaggerClient::Object::ArticleHandle;
use WWW::SwaggerClient::Object::ArticleProjectCreate;
use WWW::SwaggerClient::Object::ArticleSearch;
use WWW::SwaggerClient::Object::ArticleUpdate;
use WWW::SwaggerClient::Object::ArticleVersions;
use WWW::SwaggerClient::Object::ArticleWithProject;
use WWW::SwaggerClient::Object::ArticlesCreator;
use WWW::SwaggerClient::Object::Author;
use WWW::SwaggerClient::Object::AuthorComplete;
use WWW::SwaggerClient::Object::AuthorsCreator;
use WWW::SwaggerClient::Object::CategoriesCreator;
use WWW::SwaggerClient::Object::Category;
use WWW::SwaggerClient::Object::Collaborator;
use WWW::SwaggerClient::Object::Collection;
use WWW::SwaggerClient::Object::CollectionComplete;
use WWW::SwaggerClient::Object::CollectionCompletePrivate;
use WWW::SwaggerClient::Object::CollectionCreate;
use WWW::SwaggerClient::Object::CollectionDOI;
use WWW::SwaggerClient::Object::CollectionHandle;
use WWW::SwaggerClient::Object::CollectionPrivateLinkCreator;
use WWW::SwaggerClient::Object::CollectionSearch;
use WWW::SwaggerClient::Object::CollectionUpdate;
use WWW::SwaggerClient::Object::CollectionVersions;
use WWW::SwaggerClient::Object::CommonSearch;
use WWW::SwaggerClient::Object::ConfidentialityCreator;
use WWW::SwaggerClient::Object::CreateProjectResponse;
use WWW::SwaggerClient::Object::Curation;
use WWW::SwaggerClient::Object::CurationComment;
use WWW::SwaggerClient::Object::CurationCommentCreate;
use WWW::SwaggerClient::Object::CurationDetail;
use WWW::SwaggerClient::Object::CustomArticleField;
use WWW::SwaggerClient::Object::CustomArticleFieldAdd;
use WWW::SwaggerClient::Object::ErrorMessage;
use WWW::SwaggerClient::Object::FileCreator;
use WWW::SwaggerClient::Object::FileId;
use WWW::SwaggerClient::Object::FundingCreate;
use WWW::SwaggerClient::Object::FundingInformation;
use WWW::SwaggerClient::Object::FundingSearch;
use WWW::SwaggerClient::Object::Group;
use WWW::SwaggerClient::Object::GroupEmbargoOptions;
use WWW::SwaggerClient::Object::Institution;
use WWW::SwaggerClient::Object::InstitutionAccountsSearch;
use WWW::SwaggerClient::Object::ItemType;
use WWW::SwaggerClient::Object::License;
use WWW::SwaggerClient::Object::Location;
use WWW::SwaggerClient::Object::LocationWarnings;
use WWW::SwaggerClient::Object::LocationWarningsUpdate;
use WWW::SwaggerClient::Object::PrivateArticleSearch;
use WWW::SwaggerClient::Object::PrivateAuthorsSearch;
use WWW::SwaggerClient::Object::PrivateCollectionSearch;
use WWW::SwaggerClient::Object::PrivateFile;
use WWW::SwaggerClient::Object::PrivateLink;
use WWW::SwaggerClient::Object::PrivateLinkCreator;
use WWW::SwaggerClient::Object::PrivateLinkResponse;
use WWW::SwaggerClient::Object::Project;
use WWW::SwaggerClient::Object::ProjectArticle;
use WWW::SwaggerClient::Object::ProjectCollaborator;
use WWW::SwaggerClient::Object::ProjectCollaboratorInvite;
use WWW::SwaggerClient::Object::ProjectComplete;
use WWW::SwaggerClient::Object::ProjectCompletePrivate;
use WWW::SwaggerClient::Object::ProjectCreate;
use WWW::SwaggerClient::Object::ProjectNote;
use WWW::SwaggerClient::Object::ProjectNoteCreate;
use WWW::SwaggerClient::Object::ProjectNotePrivate;
use WWW::SwaggerClient::Object::ProjectPrivate;
use WWW::SwaggerClient::Object::ProjectUpdate;
use WWW::SwaggerClient::Object::ProjectsSearch;
use WWW::SwaggerClient::Object::PublicFile;
use WWW::SwaggerClient::Object::RelatedMaterial;
use WWW::SwaggerClient::Object::Resource;
use WWW::SwaggerClient::Object::ResponseMessage;
use WWW::SwaggerClient::Object::Role;
use WWW::SwaggerClient::Object::ShortAccount;
use WWW::SwaggerClient::Object::ShortCustomField;
use WWW::SwaggerClient::Object::Timeline;
use WWW::SwaggerClient::Object::TimelineUpdate;
use WWW::SwaggerClient::Object::UploadFilePart;
use WWW::SwaggerClient::Object::UploadInfo;
use WWW::SwaggerClient::Object::User;

# for displaying the API response data
use Data::Dumper;
use WWW::SwaggerClient::;

my $api_instance = WWW::SwaggerClient::->new(

    # Configure OAuth2 access token for authorization: OAuth2
    access_token => 'YOUR_ACCESS_TOKEN',
);

my $group_id = 789; # int | A group ID to filter by

eval {
    my $result = $api_instance->account_article_report(group_id => $group_id);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ArticlesApi->account_article_report: $@\n";
}

```

# DOCUMENTATION FOR API ENDPOINTS

All URIs are relative to *https://api.figshare.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArticlesApi* | [**account_article_report**](docs/ArticlesApi.md#account_article_report) | **GET** /account/articles/export | Account Article Report
*ArticlesApi* | [**account_article_report_generate**](docs/ArticlesApi.md#account_article_report_generate) | **POST** /account/articles/export | Initiate a new Report
*ArticlesApi* | [**article_details**](docs/ArticlesApi.md#article_details) | **GET** /articles/{article_id} | View article details
*ArticlesApi* | [**article_file_details**](docs/ArticlesApi.md#article_file_details) | **GET** /articles/{article_id}/files/{file_id} | Article file details
*ArticlesApi* | [**article_files**](docs/ArticlesApi.md#article_files) | **GET** /articles/{article_id}/files | List article files
*ArticlesApi* | [**article_version_confidentiality**](docs/ArticlesApi.md#article_version_confidentiality) | **GET** /articles/{article_id}/versions/{v_number}/confidentiality | Public Article Confidentiality for article version
*ArticlesApi* | [**article_version_details**](docs/ArticlesApi.md#article_version_details) | **GET** /articles/{article_id}/versions/{v_number} | Article details for version
*ArticlesApi* | [**article_version_embargo**](docs/ArticlesApi.md#article_version_embargo) | **GET** /articles/{article_id}/versions/{v_number}/embargo | Public Article Embargo for article version
*ArticlesApi* | [**article_version_update**](docs/ArticlesApi.md#article_version_update) | **PUT** /account/articles/{article_id}/versions/{version_id}/ | Update article version
*ArticlesApi* | [**article_version_update_thumb**](docs/ArticlesApi.md#article_version_update_thumb) | **PUT** /account/articles/{article_id}/versions/{version_id}/update_thumb | Update article version thumbnail
*ArticlesApi* | [**article_versions**](docs/ArticlesApi.md#article_versions) | **GET** /articles/{article_id}/versions | List article versions
*ArticlesApi* | [**articles_list**](docs/ArticlesApi.md#articles_list) | **GET** /articles | Public Articles
*ArticlesApi* | [**articles_search**](docs/ArticlesApi.md#articles_search) | **POST** /articles/search | Public Articles Search
*ArticlesApi* | [**private_article_author_delete**](docs/ArticlesApi.md#private_article_author_delete) | **DELETE** /account/articles/{article_id}/authors/{author_id} | Delete article author
*ArticlesApi* | [**private_article_authors_add**](docs/ArticlesApi.md#private_article_authors_add) | **POST** /account/articles/{article_id}/authors | Add article authors
*ArticlesApi* | [**private_article_authors_list**](docs/ArticlesApi.md#private_article_authors_list) | **GET** /account/articles/{article_id}/authors | List article authors
*ArticlesApi* | [**private_article_authors_replace**](docs/ArticlesApi.md#private_article_authors_replace) | **PUT** /account/articles/{article_id}/authors | Replace article authors
*ArticlesApi* | [**private_article_categories_add**](docs/ArticlesApi.md#private_article_categories_add) | **POST** /account/articles/{article_id}/categories | Add article categories
*ArticlesApi* | [**private_article_categories_list**](docs/ArticlesApi.md#private_article_categories_list) | **GET** /account/articles/{article_id}/categories | List article categories
*ArticlesApi* | [**private_article_categories_replace**](docs/ArticlesApi.md#private_article_categories_replace) | **PUT** /account/articles/{article_id}/categories | Replace article categories
*ArticlesApi* | [**private_article_category_delete**](docs/ArticlesApi.md#private_article_category_delete) | **DELETE** /account/articles/{article_id}/categories/{category_id} | Delete article category
*ArticlesApi* | [**private_article_confidentiality_delete**](docs/ArticlesApi.md#private_article_confidentiality_delete) | **DELETE** /account/articles/{article_id}/confidentiality | Delete article confidentiality
*ArticlesApi* | [**private_article_confidentiality_details**](docs/ArticlesApi.md#private_article_confidentiality_details) | **GET** /account/articles/{article_id}/confidentiality | Article confidentiality details
*ArticlesApi* | [**private_article_confidentiality_update**](docs/ArticlesApi.md#private_article_confidentiality_update) | **PUT** /account/articles/{article_id}/confidentiality | Update article confidentiality
*ArticlesApi* | [**private_article_create**](docs/ArticlesApi.md#private_article_create) | **POST** /account/articles | Create new Article
*ArticlesApi* | [**private_article_delete**](docs/ArticlesApi.md#private_article_delete) | **DELETE** /account/articles/{article_id} | Delete article
*ArticlesApi* | [**private_article_details**](docs/ArticlesApi.md#private_article_details) | **GET** /account/articles/{article_id} | Article details
*ArticlesApi* | [**private_article_embargo_delete**](docs/ArticlesApi.md#private_article_embargo_delete) | **DELETE** /account/articles/{article_id}/embargo | Delete Article Embargo
*ArticlesApi* | [**private_article_embargo_details**](docs/ArticlesApi.md#private_article_embargo_details) | **GET** /account/articles/{article_id}/embargo | Article Embargo Details
*ArticlesApi* | [**private_article_embargo_update**](docs/ArticlesApi.md#private_article_embargo_update) | **PUT** /account/articles/{article_id}/embargo | Update Article Embargo
*ArticlesApi* | [**private_article_file**](docs/ArticlesApi.md#private_article_file) | **GET** /account/articles/{article_id}/files/{file_id} | Single File
*ArticlesApi* | [**private_article_file_delete**](docs/ArticlesApi.md#private_article_file_delete) | **DELETE** /account/articles/{article_id}/files/{file_id} | File Delete
*ArticlesApi* | [**private_article_files_list**](docs/ArticlesApi.md#private_article_files_list) | **GET** /account/articles/{article_id}/files | List article files
*ArticlesApi* | [**private_article_private_link**](docs/ArticlesApi.md#private_article_private_link) | **GET** /account/articles/{article_id}/private_links | List private links
*ArticlesApi* | [**private_article_private_link_create**](docs/ArticlesApi.md#private_article_private_link_create) | **POST** /account/articles/{article_id}/private_links | Create private link
*ArticlesApi* | [**private_article_private_link_delete**](docs/ArticlesApi.md#private_article_private_link_delete) | **DELETE** /account/articles/{article_id}/private_links/{link_id} | Disable private link
*ArticlesApi* | [**private_article_private_link_update**](docs/ArticlesApi.md#private_article_private_link_update) | **PUT** /account/articles/{article_id}/private_links/{link_id} | Update private link
*ArticlesApi* | [**private_article_publish**](docs/ArticlesApi.md#private_article_publish) | **POST** /account/articles/{article_id}/publish | Private Article Publish
*ArticlesApi* | [**private_article_reserve_doi**](docs/ArticlesApi.md#private_article_reserve_doi) | **POST** /account/articles/{article_id}/reserve_doi | Private Article Reserve DOI
*ArticlesApi* | [**private_article_reserve_handle**](docs/ArticlesApi.md#private_article_reserve_handle) | **POST** /account/articles/{article_id}/reserve_handle | Private Article Reserve Handle
*ArticlesApi* | [**private_article_resource**](docs/ArticlesApi.md#private_article_resource) | **POST** /account/articles/{article_id}/resource | Private Article Resource
*ArticlesApi* | [**private_article_update**](docs/ArticlesApi.md#private_article_update) | **PUT** /account/articles/{article_id} | Update article
*ArticlesApi* | [**private_article_upload_complete**](docs/ArticlesApi.md#private_article_upload_complete) | **POST** /account/articles/{article_id}/files/{file_id} | Complete Upload
*ArticlesApi* | [**private_article_upload_initiate**](docs/ArticlesApi.md#private_article_upload_initiate) | **POST** /account/articles/{article_id}/files | Initiate Upload
*ArticlesApi* | [**private_articles_list**](docs/ArticlesApi.md#private_articles_list) | **GET** /account/articles | Private Articles
*ArticlesApi* | [**private_articles_search**](docs/ArticlesApi.md#private_articles_search) | **POST** /account/articles/search | Private Articles search
*AuthorsApi* | [**private_author_details**](docs/AuthorsApi.md#private_author_details) | **GET** /account/authors/{author_id} | Author details
*AuthorsApi* | [**private_authors_search**](docs/AuthorsApi.md#private_authors_search) | **POST** /account/authors/search | Search Authors
*CollectionsApi* | [**collection_articles**](docs/CollectionsApi.md#collection_articles) | **GET** /collections/{collection_id}/articles | Public Collection Articles
*CollectionsApi* | [**collection_details**](docs/CollectionsApi.md#collection_details) | **GET** /collections/{collection_id} | Collection details
*CollectionsApi* | [**collection_version_details**](docs/CollectionsApi.md#collection_version_details) | **GET** /collections/{collection_id}/versions/{version_id} | Collection Version details
*CollectionsApi* | [**collection_versions**](docs/CollectionsApi.md#collection_versions) | **GET** /collections/{collection_id}/versions | Collection Versions list
*CollectionsApi* | [**collections_list**](docs/CollectionsApi.md#collections_list) | **GET** /collections | Public Collections
*CollectionsApi* | [**collections_search**](docs/CollectionsApi.md#collections_search) | **POST** /collections/search | Public Collections Search
*CollectionsApi* | [**private_collection_article_delete**](docs/CollectionsApi.md#private_collection_article_delete) | **DELETE** /account/collections/{collection_id}/articles/{article_id} | Delete collection article
*CollectionsApi* | [**private_collection_articles_add**](docs/CollectionsApi.md#private_collection_articles_add) | **POST** /account/collections/{collection_id}/articles | Add collection articles
*CollectionsApi* | [**private_collection_articles_list**](docs/CollectionsApi.md#private_collection_articles_list) | **GET** /account/collections/{collection_id}/articles | List collection articles
*CollectionsApi* | [**private_collection_articles_replace**](docs/CollectionsApi.md#private_collection_articles_replace) | **PUT** /account/collections/{collection_id}/articles | Replace collection articles
*CollectionsApi* | [**private_collection_author_delete**](docs/CollectionsApi.md#private_collection_author_delete) | **DELETE** /account/collections/{collection_id}/authors/{author_id} | Delete collection author
*CollectionsApi* | [**private_collection_authors_add**](docs/CollectionsApi.md#private_collection_authors_add) | **POST** /account/collections/{collection_id}/authors | Add collection authors
*CollectionsApi* | [**private_collection_authors_list**](docs/CollectionsApi.md#private_collection_authors_list) | **GET** /account/collections/{collection_id}/authors | List collection authors
*CollectionsApi* | [**private_collection_authors_replace**](docs/CollectionsApi.md#private_collection_authors_replace) | **PUT** /account/collections/{collection_id}/authors | Replace collection authors
*CollectionsApi* | [**private_collection_categories_add**](docs/CollectionsApi.md#private_collection_categories_add) | **POST** /account/collections/{collection_id}/categories | Add collection categories
*CollectionsApi* | [**private_collection_categories_list**](docs/CollectionsApi.md#private_collection_categories_list) | **GET** /account/collections/{collection_id}/categories | List collection categories
*CollectionsApi* | [**private_collection_categories_replace**](docs/CollectionsApi.md#private_collection_categories_replace) | **PUT** /account/collections/{collection_id}/categories | Replace collection categories
*CollectionsApi* | [**private_collection_category_delete**](docs/CollectionsApi.md#private_collection_category_delete) | **DELETE** /account/collections/{collection_id}/categories/{category_id} | Delete collection category
*CollectionsApi* | [**private_collection_create**](docs/CollectionsApi.md#private_collection_create) | **POST** /account/collections | Create collection
*CollectionsApi* | [**private_collection_delete**](docs/CollectionsApi.md#private_collection_delete) | **DELETE** /account/collections/{collection_id} | Delete collection
*CollectionsApi* | [**private_collection_details**](docs/CollectionsApi.md#private_collection_details) | **GET** /account/collections/{collection_id} | Collection details
*CollectionsApi* | [**private_collection_private_link_create**](docs/CollectionsApi.md#private_collection_private_link_create) | **POST** /account/collections/{collection_id}/private_links | Create collection private link
*CollectionsApi* | [**private_collection_private_link_delete**](docs/CollectionsApi.md#private_collection_private_link_delete) | **DELETE** /account/collections/{collection_id}/private_links/{link_id} | Disable private link
*CollectionsApi* | [**private_collection_private_link_update**](docs/CollectionsApi.md#private_collection_private_link_update) | **PUT** /account/collections/{collection_id}/private_links/{link_id} | Update collection private link
*CollectionsApi* | [**private_collection_private_links_list**](docs/CollectionsApi.md#private_collection_private_links_list) | **GET** /account/collections/{collection_id}/private_links | List collection private links
*CollectionsApi* | [**private_collection_publish**](docs/CollectionsApi.md#private_collection_publish) | **POST** /account/collections/{collection_id}/publish | Private Collection Publish
*CollectionsApi* | [**private_collection_reserve_doi**](docs/CollectionsApi.md#private_collection_reserve_doi) | **POST** /account/collections/{collection_id}/reserve_doi | Private Collection Reserve DOI
*CollectionsApi* | [**private_collection_reserve_handle**](docs/CollectionsApi.md#private_collection_reserve_handle) | **POST** /account/collections/{collection_id}/reserve_handle | Private Collection Reserve Handle
*CollectionsApi* | [**private_collection_resource**](docs/CollectionsApi.md#private_collection_resource) | **POST** /account/collections/{collection_id}/resource | Private Collection Resource
*CollectionsApi* | [**private_collection_update**](docs/CollectionsApi.md#private_collection_update) | **PUT** /account/collections/{collection_id} | Update collection
*CollectionsApi* | [**private_collections_list**](docs/CollectionsApi.md#private_collections_list) | **GET** /account/collections | Private Collections List
*CollectionsApi* | [**private_collections_search**](docs/CollectionsApi.md#private_collections_search) | **POST** /account/collections/search | Private Collections Search
*InstitutionsApi* | [**account_institution_curation**](docs/InstitutionsApi.md#account_institution_curation) | **GET** /account/institution/review/{curation_id} | Institution Curation Review
*InstitutionsApi* | [**account_institution_curation_comments**](docs/InstitutionsApi.md#account_institution_curation_comments) | **GET** /account/institution/review/{curation_id}/comments | Institution Curation Review Comments
*InstitutionsApi* | [**account_institution_curation_comments_1**](docs/InstitutionsApi.md#account_institution_curation_comments_1) | **POST** /account/institution/review/{curation_id}/comments | POST Institution Curation Review Comment
*InstitutionsApi* | [**account_institution_curations**](docs/InstitutionsApi.md#account_institution_curations) | **GET** /account/institution/reviews | Institution Curation Reviews
*InstitutionsApi* | [**custom_fields_list**](docs/InstitutionsApi.md#custom_fields_list) | **GET** /account/institution/custom_fields | Private account institution group custom fields
*InstitutionsApi* | [**custom_fields_upload**](docs/InstitutionsApi.md#custom_fields_upload) | **POST** /account/institution/custom_fields/{custom_field_id}/items/upload | Custom fields values files upload
*InstitutionsApi* | [**institution_articles**](docs/InstitutionsApi.md#institution_articles) | **GET** /institutions/{institution_string_id}/articles/filter-by | Public Institution Articles
*InstitutionsApi* | [**institution_hrfeed_upload**](docs/InstitutionsApi.md#institution_hrfeed_upload) | **POST** /institution/hrfeed/upload | Private Institution HRfeed Upload
*InstitutionsApi* | [**private_account_institution_user**](docs/InstitutionsApi.md#private_account_institution_user) | **GET** /account/institution/users/{account_id} | Private Account Institution User
*InstitutionsApi* | [**private_categories_list**](docs/InstitutionsApi.md#private_categories_list) | **GET** /account/categories | Private Account Categories
*InstitutionsApi* | [**private_group_embargo_options_details**](docs/InstitutionsApi.md#private_group_embargo_options_details) | **GET** /account/institution/groups/{group_id}/embargo_options | Private Account Institution Group Embargo Options
*InstitutionsApi* | [**private_institution_account_group_role_delete**](docs/InstitutionsApi.md#private_institution_account_group_role_delete) | **DELETE** /account/institution/roles/{account_id}/{group_id}/{role_id} | Delete Institution Account Group Role
*InstitutionsApi* | [**private_institution_account_group_roles**](docs/InstitutionsApi.md#private_institution_account_group_roles) | **GET** /account/institution/roles/{account_id} | List Institution Account Group Roles
*InstitutionsApi* | [**private_institution_account_group_roles_create**](docs/InstitutionsApi.md#private_institution_account_group_roles_create) | **POST** /account/institution/roles/{account_id} | Add Institution Account Group Roles
*InstitutionsApi* | [**private_institution_accounts_create**](docs/InstitutionsApi.md#private_institution_accounts_create) | **POST** /account/institution/accounts | Create new Institution Account
*InstitutionsApi* | [**private_institution_accounts_list**](docs/InstitutionsApi.md#private_institution_accounts_list) | **GET** /account/institution/accounts | Private Account Institution Accounts
*InstitutionsApi* | [**private_institution_accounts_search**](docs/InstitutionsApi.md#private_institution_accounts_search) | **POST** /account/institution/accounts/search | Private Account Institution Accounts Search
*InstitutionsApi* | [**private_institution_accounts_update**](docs/InstitutionsApi.md#private_institution_accounts_update) | **PUT** /account/institution/accounts/{account_id} | Update Institution Account
*InstitutionsApi* | [**private_institution_articles**](docs/InstitutionsApi.md#private_institution_articles) | **GET** /account/institution/articles | Private Institution Articles
*InstitutionsApi* | [**private_institution_details**](docs/InstitutionsApi.md#private_institution_details) | **GET** /account/institution | Private Account Institutions
*InstitutionsApi* | [**private_institution_embargo_options_details**](docs/InstitutionsApi.md#private_institution_embargo_options_details) | **GET** /account/institution/embargo_options | Private Account Institution embargo options
*InstitutionsApi* | [**private_institution_groups_list**](docs/InstitutionsApi.md#private_institution_groups_list) | **GET** /account/institution/groups | Private Account Institution Groups
*InstitutionsApi* | [**private_institution_roles_list**](docs/InstitutionsApi.md#private_institution_roles_list) | **GET** /account/institution/roles | Private Account Institution Roles
*OtherApi* | [**categories_list**](docs/OtherApi.md#categories_list) | **GET** /categories | Public Categories
*OtherApi* | [**file_download**](docs/OtherApi.md#file_download) | **GET** /file/download/{file_id} | Public File Download
*OtherApi* | [**item_types_list**](docs/OtherApi.md#item_types_list) | **GET** /item_types | Item Types
*OtherApi* | [**licenses_list**](docs/OtherApi.md#licenses_list) | **GET** /licenses | Public Licenses
*OtherApi* | [**private_account**](docs/OtherApi.md#private_account) | **GET** /account | Private Account information
*OtherApi* | [**private_funding_search**](docs/OtherApi.md#private_funding_search) | **POST** /account/funding/search | Search Funding
*OtherApi* | [**private_licenses_list**](docs/OtherApi.md#private_licenses_list) | **GET** /account/licenses | Private Account Licenses
*ProjectsApi* | [**private_project_article_delete**](docs/ProjectsApi.md#private_project_article_delete) | **DELETE** /account/projects/{project_id}/articles/{article_id} | Delete project article
*ProjectsApi* | [**private_project_article_details**](docs/ProjectsApi.md#private_project_article_details) | **GET** /account/projects/{project_id}/articles/{article_id} | Project article details
*ProjectsApi* | [**private_project_article_file**](docs/ProjectsApi.md#private_project_article_file) | **GET** /account/projects/{project_id}/articles/{article_id}/files/{file_id} | Project article file details
*ProjectsApi* | [**private_project_article_files**](docs/ProjectsApi.md#private_project_article_files) | **GET** /account/projects/{project_id}/articles/{article_id}/files | Project article list files
*ProjectsApi* | [**private_project_articles_create**](docs/ProjectsApi.md#private_project_articles_create) | **POST** /account/projects/{project_id}/articles | Create project article
*ProjectsApi* | [**private_project_articles_list**](docs/ProjectsApi.md#private_project_articles_list) | **GET** /account/projects/{project_id}/articles | List project articles
*ProjectsApi* | [**private_project_collaborator_delete**](docs/ProjectsApi.md#private_project_collaborator_delete) | **DELETE** /account/projects/{project_id}/collaborators/{user_id} | Remove project collaborator
*ProjectsApi* | [**private_project_collaborators_invite**](docs/ProjectsApi.md#private_project_collaborators_invite) | **POST** /account/projects/{project_id}/collaborators | Invite project collaborators
*ProjectsApi* | [**private_project_collaborators_list**](docs/ProjectsApi.md#private_project_collaborators_list) | **GET** /account/projects/{project_id}/collaborators | List project collaborators
*ProjectsApi* | [**private_project_create**](docs/ProjectsApi.md#private_project_create) | **POST** /account/projects | Create project
*ProjectsApi* | [**private_project_delete**](docs/ProjectsApi.md#private_project_delete) | **DELETE** /account/projects/{project_id} | Delete project
*ProjectsApi* | [**private_project_details**](docs/ProjectsApi.md#private_project_details) | **GET** /account/projects/{project_id} | View project details
*ProjectsApi* | [**private_project_leave**](docs/ProjectsApi.md#private_project_leave) | **POST** /account/projects/{project_id}/leave | Private Project Leave
*ProjectsApi* | [**private_project_note**](docs/ProjectsApi.md#private_project_note) | **GET** /account/projects/{project_id}/notes/{note_id} | Project note details
*ProjectsApi* | [**private_project_note_delete**](docs/ProjectsApi.md#private_project_note_delete) | **DELETE** /account/projects/{project_id}/notes/{note_id} | Delete project note
*ProjectsApi* | [**private_project_note_update**](docs/ProjectsApi.md#private_project_note_update) | **PUT** /account/projects/{project_id}/notes/{note_id} | Update project note
*ProjectsApi* | [**private_project_notes_create**](docs/ProjectsApi.md#private_project_notes_create) | **POST** /account/projects/{project_id}/notes | Create project note
*ProjectsApi* | [**private_project_notes_list**](docs/ProjectsApi.md#private_project_notes_list) | **GET** /account/projects/{project_id}/notes | List project notes
*ProjectsApi* | [**private_project_publish**](docs/ProjectsApi.md#private_project_publish) | **POST** /account/projects/{project_id}/publish | Private Project Publish
*ProjectsApi* | [**private_project_update**](docs/ProjectsApi.md#private_project_update) | **PUT** /account/projects/{project_id} | Update project
*ProjectsApi* | [**private_projects_list**](docs/ProjectsApi.md#private_projects_list) | **GET** /account/projects | Private Projects
*ProjectsApi* | [**private_projects_search**](docs/ProjectsApi.md#private_projects_search) | **POST** /account/projects/search | Private Projects search
*ProjectsApi* | [**project_articles**](docs/ProjectsApi.md#project_articles) | **GET** /projects/{project_id}/articles | Public Project Articles
*ProjectsApi* | [**project_details**](docs/ProjectsApi.md#project_details) | **GET** /projects/{project_id} | Public Project
*ProjectsApi* | [**projects_list**](docs/ProjectsApi.md#projects_list) | **GET** /projects | Public Projects
*ProjectsApi* | [**projects_search**](docs/ProjectsApi.md#projects_search) | **POST** /projects/search | Public Projects Search


# DOCUMENTATION FOR MODELS
 - [WWW::SwaggerClient::Object::Account](docs/Account.md)
 - [WWW::SwaggerClient::Object::AccountCreate](docs/AccountCreate.md)
 - [WWW::SwaggerClient::Object::AccountGroupRoles](docs/AccountGroupRoles.md)
 - [WWW::SwaggerClient::Object::AccountGroupRolesCreate](docs/AccountGroupRolesCreate.md)
 - [WWW::SwaggerClient::Object::AccountReport](docs/AccountReport.md)
 - [WWW::SwaggerClient::Object::AccountUpdate](docs/AccountUpdate.md)
 - [WWW::SwaggerClient::Object::Article](docs/Article.md)
 - [WWW::SwaggerClient::Object::ArticleComplete](docs/ArticleComplete.md)
 - [WWW::SwaggerClient::Object::ArticleCompletePrivate](docs/ArticleCompletePrivate.md)
 - [WWW::SwaggerClient::Object::ArticleConfidentiality](docs/ArticleConfidentiality.md)
 - [WWW::SwaggerClient::Object::ArticleCreate](docs/ArticleCreate.md)
 - [WWW::SwaggerClient::Object::ArticleDOI](docs/ArticleDOI.md)
 - [WWW::SwaggerClient::Object::ArticleEmbargo](docs/ArticleEmbargo.md)
 - [WWW::SwaggerClient::Object::ArticleEmbargoUpdater](docs/ArticleEmbargoUpdater.md)
 - [WWW::SwaggerClient::Object::ArticleHandle](docs/ArticleHandle.md)
 - [WWW::SwaggerClient::Object::ArticleProjectCreate](docs/ArticleProjectCreate.md)
 - [WWW::SwaggerClient::Object::ArticleSearch](docs/ArticleSearch.md)
 - [WWW::SwaggerClient::Object::ArticleUpdate](docs/ArticleUpdate.md)
 - [WWW::SwaggerClient::Object::ArticleVersions](docs/ArticleVersions.md)
 - [WWW::SwaggerClient::Object::ArticleWithProject](docs/ArticleWithProject.md)
 - [WWW::SwaggerClient::Object::ArticlesCreator](docs/ArticlesCreator.md)
 - [WWW::SwaggerClient::Object::Author](docs/Author.md)
 - [WWW::SwaggerClient::Object::AuthorComplete](docs/AuthorComplete.md)
 - [WWW::SwaggerClient::Object::AuthorsCreator](docs/AuthorsCreator.md)
 - [WWW::SwaggerClient::Object::CategoriesCreator](docs/CategoriesCreator.md)
 - [WWW::SwaggerClient::Object::Category](docs/Category.md)
 - [WWW::SwaggerClient::Object::Collaborator](docs/Collaborator.md)
 - [WWW::SwaggerClient::Object::Collection](docs/Collection.md)
 - [WWW::SwaggerClient::Object::CollectionComplete](docs/CollectionComplete.md)
 - [WWW::SwaggerClient::Object::CollectionCompletePrivate](docs/CollectionCompletePrivate.md)
 - [WWW::SwaggerClient::Object::CollectionCreate](docs/CollectionCreate.md)
 - [WWW::SwaggerClient::Object::CollectionDOI](docs/CollectionDOI.md)
 - [WWW::SwaggerClient::Object::CollectionHandle](docs/CollectionHandle.md)
 - [WWW::SwaggerClient::Object::CollectionPrivateLinkCreator](docs/CollectionPrivateLinkCreator.md)
 - [WWW::SwaggerClient::Object::CollectionSearch](docs/CollectionSearch.md)
 - [WWW::SwaggerClient::Object::CollectionUpdate](docs/CollectionUpdate.md)
 - [WWW::SwaggerClient::Object::CollectionVersions](docs/CollectionVersions.md)
 - [WWW::SwaggerClient::Object::CommonSearch](docs/CommonSearch.md)
 - [WWW::SwaggerClient::Object::ConfidentialityCreator](docs/ConfidentialityCreator.md)
 - [WWW::SwaggerClient::Object::CreateProjectResponse](docs/CreateProjectResponse.md)
 - [WWW::SwaggerClient::Object::Curation](docs/Curation.md)
 - [WWW::SwaggerClient::Object::CurationComment](docs/CurationComment.md)
 - [WWW::SwaggerClient::Object::CurationCommentCreate](docs/CurationCommentCreate.md)
 - [WWW::SwaggerClient::Object::CurationDetail](docs/CurationDetail.md)
 - [WWW::SwaggerClient::Object::CustomArticleField](docs/CustomArticleField.md)
 - [WWW::SwaggerClient::Object::CustomArticleFieldAdd](docs/CustomArticleFieldAdd.md)
 - [WWW::SwaggerClient::Object::ErrorMessage](docs/ErrorMessage.md)
 - [WWW::SwaggerClient::Object::FileCreator](docs/FileCreator.md)
 - [WWW::SwaggerClient::Object::FileId](docs/FileId.md)
 - [WWW::SwaggerClient::Object::FundingCreate](docs/FundingCreate.md)
 - [WWW::SwaggerClient::Object::FundingInformation](docs/FundingInformation.md)
 - [WWW::SwaggerClient::Object::FundingSearch](docs/FundingSearch.md)
 - [WWW::SwaggerClient::Object::Group](docs/Group.md)
 - [WWW::SwaggerClient::Object::GroupEmbargoOptions](docs/GroupEmbargoOptions.md)
 - [WWW::SwaggerClient::Object::Institution](docs/Institution.md)
 - [WWW::SwaggerClient::Object::InstitutionAccountsSearch](docs/InstitutionAccountsSearch.md)
 - [WWW::SwaggerClient::Object::ItemType](docs/ItemType.md)
 - [WWW::SwaggerClient::Object::License](docs/License.md)
 - [WWW::SwaggerClient::Object::Location](docs/Location.md)
 - [WWW::SwaggerClient::Object::LocationWarnings](docs/LocationWarnings.md)
 - [WWW::SwaggerClient::Object::LocationWarningsUpdate](docs/LocationWarningsUpdate.md)
 - [WWW::SwaggerClient::Object::PrivateArticleSearch](docs/PrivateArticleSearch.md)
 - [WWW::SwaggerClient::Object::PrivateAuthorsSearch](docs/PrivateAuthorsSearch.md)
 - [WWW::SwaggerClient::Object::PrivateCollectionSearch](docs/PrivateCollectionSearch.md)
 - [WWW::SwaggerClient::Object::PrivateFile](docs/PrivateFile.md)
 - [WWW::SwaggerClient::Object::PrivateLink](docs/PrivateLink.md)
 - [WWW::SwaggerClient::Object::PrivateLinkCreator](docs/PrivateLinkCreator.md)
 - [WWW::SwaggerClient::Object::PrivateLinkResponse](docs/PrivateLinkResponse.md)
 - [WWW::SwaggerClient::Object::Project](docs/Project.md)
 - [WWW::SwaggerClient::Object::ProjectArticle](docs/ProjectArticle.md)
 - [WWW::SwaggerClient::Object::ProjectCollaborator](docs/ProjectCollaborator.md)
 - [WWW::SwaggerClient::Object::ProjectCollaboratorInvite](docs/ProjectCollaboratorInvite.md)
 - [WWW::SwaggerClient::Object::ProjectComplete](docs/ProjectComplete.md)
 - [WWW::SwaggerClient::Object::ProjectCompletePrivate](docs/ProjectCompletePrivate.md)
 - [WWW::SwaggerClient::Object::ProjectCreate](docs/ProjectCreate.md)
 - [WWW::SwaggerClient::Object::ProjectNote](docs/ProjectNote.md)
 - [WWW::SwaggerClient::Object::ProjectNoteCreate](docs/ProjectNoteCreate.md)
 - [WWW::SwaggerClient::Object::ProjectNotePrivate](docs/ProjectNotePrivate.md)
 - [WWW::SwaggerClient::Object::ProjectPrivate](docs/ProjectPrivate.md)
 - [WWW::SwaggerClient::Object::ProjectUpdate](docs/ProjectUpdate.md)
 - [WWW::SwaggerClient::Object::ProjectsSearch](docs/ProjectsSearch.md)
 - [WWW::SwaggerClient::Object::PublicFile](docs/PublicFile.md)
 - [WWW::SwaggerClient::Object::RelatedMaterial](docs/RelatedMaterial.md)
 - [WWW::SwaggerClient::Object::Resource](docs/Resource.md)
 - [WWW::SwaggerClient::Object::ResponseMessage](docs/ResponseMessage.md)
 - [WWW::SwaggerClient::Object::Role](docs/Role.md)
 - [WWW::SwaggerClient::Object::ShortAccount](docs/ShortAccount.md)
 - [WWW::SwaggerClient::Object::ShortCustomField](docs/ShortCustomField.md)
 - [WWW::SwaggerClient::Object::Timeline](docs/Timeline.md)
 - [WWW::SwaggerClient::Object::TimelineUpdate](docs/TimelineUpdate.md)
 - [WWW::SwaggerClient::Object::UploadFilePart](docs/UploadFilePart.md)
 - [WWW::SwaggerClient::Object::UploadInfo](docs/UploadInfo.md)
 - [WWW::SwaggerClient::Object::User](docs/User.md)


# DOCUMENTATION FOR AUTHORIZATION

## OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://figshare.com/account/applications/authorize
- **Scopes**: 
  - **all**: Grants all access

